@@ -77,13 +77,12 @@ sub translate {
 				}
 				fillattribs($value, $attrhash, $langnode, $h, scalar(@langnodes));
 			}
-		}
-		else {
+		} else {
 			# no language, try node content, else stick to the org value
 			$h->{value} = $node->nodeName();
 			$h->{value} = $value unless ($h->{value});
 			fillattribs($value, $attrhash, $node, $h, 1);
-		}
+		}	
 	} else {
 		# nothing found, might want to write this to stderr?
 		carp "babelfish: nothing found for: $value";
@@ -93,47 +92,41 @@ sub translate {
 	return $h->{value};
 }
 
-sub fillattribs
-{
-  my ( $value,$attrhash,$node,$h,$number)=@_;
+sub fillattribs {
+  my ($value, $attrhash, $node, $h, $number) = @_;
   #attribs
-  foreach my $attrib (keys %$attrhash)
-  {
+  foreach my $attrib (keys %$attrhash) {
     my $attribvalue=$node->getAttribute($attrib);
 
     #multiline
-    if ($number > 1)
-    {
-      if ($attribvalue)
-      {
-	push (@{$h->{$attrib}},$attribvalue);
+    if ($number > 1) {
+      if ($attribvalue) {
+		  push (@{$h->{$attrib}},$attribvalue);
+      } else {
+		  push (@{$h->{$attrib}},undef) if ($attrhash->{$attrib}); # was: $h->{value}
       }
-      else
-      {
-	push (@{$h->{$attrib}},undef) if ($attrhash->{$attrib}); # was: $h->{value}
-      }
-    }
-
-    #singleline
-    else
-    {
+    } else {
+      #singleline
       $h->{$attrib}=$attribvalue;
     }
-    unless ($h->{$attrib})
-    {
-      $h->{$attrib}=undef if ($attrhash->{$attrib}); # was: $h->{value}
+
+    unless ($h->{$attrib}) {
+      $h->{$attrib} = undef if $attrhash->{$attrib}; # was: $h->{value}
     }
   }
 }
 
 
-sub getbrowserlanguage
-{
+sub getbrowserlanguage {
   my $self=shift;
-  my $lan= lc($ENV{'HTTP_ACCEPT_LANGUAGE'});
+  my $lan= $ENV{'HTTP_ACCEPT_LANGUAGE'};
+  if ($lan){
+	  $lan = lc($lan);
+  } else {
+	  $lan = 'en';
+  }
 
-  if ($self->{fields}->{language})
-  {
+  if ($self->{fields}->{language}) {
     $self->debug( "request language: $self->{fields}->{language}");
     return 'en' if ($self->{fields}->{language} eq 'en');
     return 'nl' if ($self->{fields}->{language} eq 'nl');
@@ -145,15 +138,11 @@ sub getbrowserlanguage
   my $en = index ($lan,'en')+1;
   my $res='en';
 
-  if ($nl && $en)
-  {
-    if ($nl < $en)
-    {
+  if ($nl && $en)  {
+    if ($nl < $en) {
       $res='nl';
     }
-  }
-  elsif ($nl)
-  {
+  } elsif ($nl) {
     $res='nl';
   }
   $self->{fields}->{language}=$res;
